diff --git a/packages/cli/src/config/footerItems.ts b/packages/cli/src/config/footerItems.ts
index 49c851f5ae..ba3c4a1307 100644
--- a/packages/cli/src/config/footerItems.ts
+++ b/packages/cli/src/config/footerItems.ts
@@ -9,17 +9,17 @@ import type { MergedSettings } from './settings.js';
export const ALL_ITEMS = [
{
id: 'cwd',
- header: 'Path',
+ header: 'workspace (/directory)',
description: 'Current working directory',
},
{
id: 'git-branch',
- header: 'Branch',
+ header: 'branch',
description: 'Current git branch name (not shown when unavailable)',
},
{
id: 'sandbox-status',
- header: '/docs',
+ header: 'sandbox',
description: 'Sandbox type and trust indicator',
},
{
@@ -29,7 +29,7 @@ export const ALL_ITEMS = [
},
{
id: 'context-remaining',
- header: 'Context',
+ header: 'context',
description: 'Percentage of context window remaining',
},
{
@@ -39,22 +39,22 @@ export const ALL_ITEMS = [
},
{
id: 'memory-usage',
- header: 'Memory',
+ header: 'memory',
description: 'Memory used by the application',
},
{
id: 'session-id',
- header: 'Session',
+ header: 'session',
description: 'Unique identifier for the current session',
},
{
id: 'code-changes',
- header: 'Diff',
+ header: 'diff',
description: 'Lines added/removed in the session (not shown when zero)',
},
{
id: 'token-count',
- header: 'Tokens',
+ header: 'tokens',
description: 'Total tokens used in the session (not shown when zero)',
},
] as const;
diff --git a/packages/cli/src/config/settingsSchema.ts b/packages/cli/src/config/settingsSchema.ts
index ccca95b147..85655bfb49 100644
--- a/packages/cli/src/config/settingsSchema.ts
+++ b/packages/cli/src/config/settingsSchema.ts
@@ -598,8 +598,7 @@ const SETTINGS_SCHEMA = {
category: 'UI',
requiresRestart: false,
default: false,
- description:
- 'Hide the current working directory path in the footer.',
+ description: 'Hide the current working directory in the footer.',
showInDialog: true,
},
hideSandboxStatus: {
diff --git a/packages/cli/src/ui/components/Footer.test.tsx b/packages/cli/src/ui/components/Footer.test.tsx
index d8892d0b28..92ae87e6d8 100644
--- a/packages/cli/src/ui/components/Footer.test.tsx
+++ b/packages/cli/src/ui/components/Footer.test.tsx
@@ -622,7 +622,7 @@ describe('', () => {
const output = lastFrame();
const modelIdx = output.indexOf('/model');
- const cwdIdx = output.indexOf('Path');
+ const cwdIdx = output.indexOf('workspace (/directory)');
expect(modelIdx).toBeLessThan(cwdIdx);
unmount();
});
@@ -653,9 +653,9 @@ describe('', () => {
const output = lastFrame();
expect(output).toBeDefined();
// Headers should be present
- expect(output).toContain('Path');
- expect(output).toContain('Branch');
- expect(output).toContain('/docs');
+ expect(output).toContain('workspace (/directory)');
+ expect(output).toContain('branch');
+ expect(output).toContain('sandbox');
expect(output).toContain('/model');
// Data should be present
expect(output).toContain('main');
@@ -708,8 +708,8 @@ describe('', () => {
const output = lastFrame();
expect(output).toBeDefined();
- expect(output).not.toContain('Branch');
- expect(output).toContain('Path');
+ expect(output).not.toContain('branch');
+ expect(output).toContain('workspace (/directory)');
expect(output).toContain('/model');
unmount();
});
diff --git a/packages/cli/src/ui/components/FooterConfigDialog.tsx b/packages/cli/src/ui/components/FooterConfigDialog.tsx
index 74a532585c..7652e01973 100644
--- a/packages/cli/src/ui/components/FooterConfigDialog.tsx
+++ b/packages/cli/src/ui/components/FooterConfigDialog.tsx
@@ -146,7 +146,7 @@ export const FooterConfigDialog: React.FC = ({
if (!item) return null;
return {
key: id,
- label: id,
+ label: item.header,
description: item.description as string,
};
})
diff --git a/packages/cli/src/ui/components/__snapshots__/Footer.test.tsx.snap b/packages/cli/src/ui/components/__snapshots__/Footer.test.tsx.snap
index b0b76218b1..6a59ce6dfc 100644
--- a/packages/cli/src/ui/components/__snapshots__/Footer.test.tsx.snap
+++ b/packages/cli/src/ui/components/__snapshots__/Footer.test.tsx.snap
@@ -1,31 +1,31 @@
// Vitest Snapshot v1, https://vitest.dev/guide/snapshot.html
exports[` > displays "Limit reached" message when remaining is 0 1`] = `
-" Path /docs /model /stats
+" workspace (/directory) sandbox /model /stats
~/project/foo/bar/and/some/more/directories/to/make/it/long no sandbox gemini-pro limit reached
"
`;
exports[` > displays the usage indicator when usage is low 1`] = `
-" Path /docs /model /stats
+" workspace (/directory) sandbox /model /stats
~/project/foo/bar/and/some/more/directories/to/make/it/long no sandbox gemini-pro daily 15%
"
`;
exports[` > footer configuration filtering (golden snapshots) > renders complete footer in narrow terminal (baseline narrow) > complete-footer-narrow 1`] = `
-" Path /docs /model Context
+" workspace (/directory) sandbox /model context
~/.../more/directories/to/make/it/long no sandbox gemini-pro 86%
"
`;
exports[` > footer configuration filtering (golden snapshots) > renders complete footer with all sections visible (baseline) > complete-footer-wide 1`] = `
-" Path /docs /model Context
+" workspace (/directory) sandbox /model context
~/project/foo/bar/and/some/more/directories/to/make/it/long no sandbox gemini-pro 86% left
"
`;
exports[` > footer configuration filtering (golden snapshots) > renders footer with CWD and model info hidden to test alignment (only sandbox visible) > footer-only-sandbox 1`] = `
-" /docs
+" sandbox
no sandbox
"
`;
@@ -33,13 +33,13 @@ exports[` > footer configuration filtering (golden snapshots) > render
exports[` > footer configuration filtering (golden snapshots) > renders footer with all optional sections hidden (minimal footer) > footer-minimal 1`] = `""`;
exports[` > footer configuration filtering (golden snapshots) > renders footer with only model info hidden (partial filtering) > footer-no-model 1`] = `
-" Path /docs
+" workspace (/directory) sandbox
~/project/foo/bar/and/some/more/directories/to/make/it/long no sandbox
"
`;
exports[` > hides the usage indicator when usage is not near limit 1`] = `
-" Path /docs /model /stats
+" workspace (/directory) sandbox /model /stats
~/project/foo/bar/and/some/more/directories/to/make/it/long no sandbox gemini-pro daily 85%
"
`;
diff --git a/packages/cli/src/ui/components/__snapshots__/FooterConfigDialog.test.tsx.snap b/packages/cli/src/ui/components/__snapshots__/FooterConfigDialog.test.tsx.snap
index 85f03e8786..a1bb87f9db 100644
--- a/packages/cli/src/ui/components/__snapshots__/FooterConfigDialog.test.tsx.snap
+++ b/packages/cli/src/ui/components/__snapshots__/FooterConfigDialog.test.tsx.snap
@@ -7,16 +7,16 @@ exports[` > renders correctly with default settings 1`] =
│ │
│ Select which items to display in the footer. │
│ │
-│ > [✓] cwd Current working directory │
-│ [✓] git-branch Current git branch name (not shown when unavailable) │
-│ [✓] sandbox-status Sandbox type and trust indicator │
-│ [✓] model-name Current model identifier │
-│ [✓] usage-limit Remaining usage on daily limit (not shown when unavailable) │
-│ [ ] context-remaining Percentage of context window remaining │
-│ [ ] memory-usage Memory used by the application │
-│ [ ] session-id Unique identifier for the current session │
-│ [ ] code-changes Lines added/removed in the session (not shown when zero) │
-│ [ ] token-count Total tokens used in the session (not shown when zero) │
+│ > [✓] workspace (/directory) Current working directory │
+│ [✓] branch Current git branch name (not shown when unavailable) │
+│ [✓] sandbox Sandbox type and trust indicator │
+│ [✓] /model Current model identifier │
+│ [✓] /stats Remaining usage on daily limit (not shown when unavailable) │
+│ [ ] context Percentage of context window remaining │
+│ [ ] memory Memory used by the application │
+│ [ ] session Unique identifier for the current session │
+│ [ ] diff Lines added/removed in the session (not shown when zero) │
+│ [ ] tokens Total tokens used in the session (not shown when zero) │
│ │
│ [✓] Show footer labels │
│ Reset to default footer │
@@ -25,8 +25,8 @@ exports[` > renders correctly with default settings 1`] =
│ │
│ ┌────────────────────────────────────────────────────────────────────────────────────────────┐ │
│ │ Preview: │ │
-│ │ Path Branch /docs /model /stats │ │
-│ │ ~/project/path main docker gemini-2.5-pro daily 97% │ │
+│ │ workspace (/directory) branch sandbox /model /stats │ │
+│ │ ~/project/path main docker gemini-2.5-pro daily 97% │ │
│ └────────────────────────────────────────────────────────────────────────────────────────────┘ │
│ │
╰──────────────────────────────────────────────────────────────────────────────────────────────────╯
diff --git a/packages/cli/src/ui/components/FooterConfigDialog.test.tsx b/packages/cli/src/ui/components/FooterConfigDialog.test.tsx
index 07dc6a7859..337d12d453 100644
--- a/packages/cli/src/ui/components/FooterConfigDialog.test.tsx
+++ b/packages/cli/src/ui/components/FooterConfigDialog.test.tsx
@@ -46,7 +46,7 @@ describe('', () => {
});
await waitFor(() => {
- expect(lastFrame()).toContain('[ ] cwd');
+ expect(lastFrame()).toContain('[ ] workspace (/directory)');
});
act(() => {
@@ -54,7 +54,7 @@ describe('', () => {
});
await waitFor(() => {
- expect(lastFrame()).toContain('[✓] cwd');
+ expect(lastFrame()).toContain('[✓] workspace (/directory)');
});
});
@@ -66,23 +66,23 @@ describe('', () => {
);
await waitUntilReady();
// Initial order: cwd, git-branch, ...
const output = lastFrame();
- const cwdIdx = output!.indexOf('] cwd');
- const branchIdx = output!.indexOf('] git-branch');
+ const cwdIdx = output.indexOf('] workspace (/directory)');
+ const branchIdx = output.indexOf('] branch');
expect(cwdIdx).toBeGreaterThan(-1);
expect(branchIdx).toBeGreaterThan(-1);
expect(cwdIdx).toBeLessThan(branchIdx);
// Move cwd down (right arrow)
act(() => {
stdin.write('\u001b[C'); // Right arrow
});
await waitFor(() => {
const outputAfter = lastFrame();
- const cwdIdxAfter = outputAfter!.indexOf('] cwd');
- const branchIdxAfter = outputAfter!.indexOf('] git-branch');
+ const cwdIdxAfter = outputAfter.indexOf('] workspace (/directory)');
+ const branchIdxAfter = outputAfter.indexOf('] branch');
expect(cwdIdxAfter).toBeGreaterThan(-1);
expect(branchIdxAfter).toBeGreaterThan(-1);
expect(branchIdxAfter).toBeLessThan(cwdIdxAfter);
@@ -66,23 +66,23 @@ describe('', () => {
);
await waitUntilReady();
- // Initial order: cwd, git-branch, ...
+ // Initial order: workspace (/directory), branch, ...
const output = lastFrame();
@@ -66,23 +66,23 @@ describe('', () => {
expect(branchIdx).toBeGreaterThan(-1);
expect(cwdIdx).toBeLessThan(branchIdx);
- // Move cwd down (right arrow)
+ // Move workspace (/directory) down (right arrow)
act(() => {
stdin.write('\u001b[C'); // Right arrow